documentFactory.SQLDocumentStream

|  | ## Cheshire3 Object Model: Class SQLDocumentStream

Module documentFactory :: Class SQLDocumentStream

## Class SQLDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
      RemoteDocumentStream --+
                             |
                            SQLDocumentStream

Instance Methods

Inherited from `RemoteDocumentStream`: `parse_url` Inherited from `BaseDocumentStream`: `__init__`, `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`